
{%- include 'datatable_header.j2' %}
{%- if "Tenant" in api %}
<h1>Tenants</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>User Domain</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for tenant in data_to_template['imdata'] %}
  <tr>
    <td>{{ tenant.fvTenant.attributes.name }}</td>
    <td>{{ tenant.fvTenant.attributes.nameAlias }}</td>
    <td>{{ tenant.fvTenant.attributes.descr }}</td>
    <td>{{ tenant.fvTenant.attributes.status }}</td>
    <td>{{ tenant.fvTenant.attributes.dn }}</td>
    <td>{{ tenant.fvTenant.attributes.uid }}</td>
    <td>{{ tenant.fvTenant.attributes.annotation }}</td>
    <td>{{ tenant.fvTenant.attributes.childAction }}</td>
    <td>{{ tenant.fvTenant.attributes.extMngdBy }}</td>
    <td>{{ tenant.fvTenant.attributes.lcOwn }}</td>
    <td>{{ tenant.fvTenant.attributes.monPolDn }}</td>
    <td>{{ tenant.fvTenant.attributes.ownerKey }}</td>
    <td>{{ tenant.fvTenant.attributes.ownerTag }}</td>
    <td>{{ tenant.fvTenant.attributes.userdom }}</td>
    <td>{{ tenant.fvTenant.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "AEPg" in api %}
<h1>Endpoint Groups</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Configuration Issues</th>
    <th>Configuration State</th>
    <th>Exception Tag</th>
    <th>Flood On Encapsulation</th>
    <th>Forward Control</th>
    <th>Has Multicast Source</th>
    <th>Is Attribute Based EPG</th>
    <th>Is Shared Service Multicast Site EPG</th>
    <th>Match T</th>
    <th>PC Enforcement Preference</th>
    <th>PC Tag</th>
    <th>PC Tag Allocation Source</th>
    <th>Preference Gr Member</th>
    <th>Priority</th>
    <th>Scope</th>
    <th>Shutdown</th>
    <th>Trigger State</th>
    <th>TX Id</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for epg in data_to_template['imdata'] %}
  <tr>
    <td>{{ epg.fvAEPg.attributes.name }}</td>
    <td>{{ epg.fvAEPg.attributes.nameAlias }}</td>
    <td>{{ epg.fvAEPg.attributes.descr }}</td>
    <td>{{ epg.fvAEPg.attributes.status }}</td>
    <td>{{ epg.fvAEPg.attributes.dn }}</td>
    <td>{{ epg.fvAEPg.attributes.uid }}</td>
    <td>{{ epg.fvAEPg.attributes.annotation }}</td>
    <td>{{ epg.fvAEPg.attributes.childAction }}</td>
    <td>{{ epg.fvAEPg.attributes.extMngdBy }}</td>
    <td>{{ epg.fvAEPg.attributes.lcOwn }}</td>
    <td>{{ epg.fvAEPg.attributes.monPolDn }}</td>
    <td>{{ epg.fvAEPg.attributes.userdom }}</td>
    <td>{{ epg.fvAEPg.attributes.configIssues }}</td>
    <td>{{ epg.fvAEPg.attributes.configSt }}</td>
    <td>{{ epg.fvAEPg.attributes.exceptionTag }}</td>
    <td>{{ epg.fvAEPg.attributes.floodOnEncap }}</td>
    <td>{{ epg.fvAEPg.attributes.fwdCtrl }}</td>
    <td>{{ epg.fvAEPg.attributes.hasMcastSource }}</td>
    <td>{{ epg.fvAEPg.attributes.isAttrBasedEPg }}</td>
    <td>{{ epg.fvAEPg.attributes.isSharedSrvMsiteEPg }}</td>
    <td>{{ epg.fvAEPg.attributes.matchT }}</td>
    <td>{{ epg.fvAEPg.attributes.pcEnfPref }}</td>
    <td>{{ epg.fvAEPg.attributes.pcTag }}</td>
    <td>{{ epg.fvAEPg.attributes.pcTagAllocSrc }}</td>
    <td>{{ epg.fvAEPg.attributes.prefGrMemb }}</td>
    <td>{{ epg.fvAEPg.attributes.prio }}</td>
    <td>{{ epg.fvAEPg.attributes.scope }}</td>
    <td>{{ epg.fvAEPg.attributes.shutdown }}</td>
    <td>{{ epg.fvAEPg.attributes.triggerSt }}</td>
    <td>{{ epg.fvAEPg.attributes.txId }}</td>
    <td>{{ epg.fvAEPg.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "BD" in api %}
<h1>Bridge Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Configuration Issues</th>
    <th>Optimize Wan Bandwidth</th>
    <th>ARP Flood</th>
    <th>Broadcast P</th>
    <th>Endpoint Clear</th>
    <th>Endpoint Move Detect Mode</th>
    <th>Host Based Routing</th>
    <th>Intersite BUM Traffic Allow</th>
    <th>Intersite L2 Stretch</th>
    <th>IP Learning</th>
    <th>IPv6 Multicast Allow</th>
    <th>Limit IP Learn To Subnets</th>
    <th>Link Local Address</th>
    <th>MAC</th>
    <th>Multicast Allow</th>
    <th>MTU</th>
    <th>Multicase Destination Packet Action</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>PC Tag</th>
    <th>Scope</th>
    <th>Segment</th>
    <th>Type</th>
    <th>Unicast Route</th>
    <th>Unknown MAC Unicast Action</th>
    <th>Unknown Multicast Action</th>
    <th>IPv6 Unknown Multicast Action</th>
    <th>Virtual MAC</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>  
<tbody>
{%-     for bd in data_to_template['imdata'] %}
  <tr>
    <td>{{ bd.fvBD.attributes.name }}</td>
    <td>{{ bd.fvBD.attributes.nameAlias }}</td>
    <td>{{ bd.fvBD.attributes.descr }}</td>
    <td>{{ bd.fvBD.attributes.status }}</td>
    <td>{{ bd.fvBD.attributes.dn }}</td>
    <td>{{ bd.fvBD.attributes.uid }}</td>
    <td>{{ bd.fvBD.attributes.annotation }}</td>
    <td>{{ bd.fvBD.attributes.childAction }}</td>
    <td>{{ bd.fvBD.attributes.extMngdBy }}</td>
    <td>{{ bd.fvBD.attributes.lcOwn }}</td>
    <td>{{ bd.fvBD.attributes.monPolDn }}</td>
    <td>{{ bd.fvBD.attributes.userdom }}</td>
    <td>{{ bd.fvBD.attributes.configIssues }}</td>
    <td>{{ bd.fvBD.attributes.OptimizeWanBandwidth }}</td>
    <td>{{ bd.fvBD.attributes.arpFlood }}</td>
    <td>{{ bd.fvBD.attributes.bcastP }}</td>
    <td>{{ bd.fvBD.attributes.epClear }}</td>
    <td>{{ bd.fvBD.attributes.epMoveDetectMode }}</td>
    <td>{{ bd.fvBD.attributes.hostBasedRouting }}</td>
    <td>{{ bd.fvBD.attributes.intersiteBumTrafficAllow }}</td>
    <td>{{ bd.fvBD.attributes.intersiteL2Stretch }}</td>
    <td>{{ bd.fvBD.attributes.ipLearning }}</td>
    <td>{{ bd.fvBD.attributes.ipv6McastAllow }}</td>
    <td>{{ bd.fvBD.attributes.limitIpLearnToSubnets }}</td>
    <td>{{ bd.fvBD.attributes.llAddr }}</td>
    <td>{{ bd.fvBD.attributes.mac }}</td>
    <td>{{ bd.fvBD.attributes.mcastAllow }}</td>
    <td>{{ bd.fvBD.attributes.mtu }}</td>
    <td>{{ bd.fvBD.attributes.multiDstPktAct }}</td>
    <td>{{ bd.fvBD.attributes.ownerKey }}</td>
    <td>{{ bd.fvBD.attributes.ownerTag }}</td>
    <td>{{ bd.fvBD.attributes.pcTag }}</td>
    <td>{{ bd.fvBD.attributes.scope }}</td>
    <td>{{ bd.fvBD.attributes.seg }}</td>
    <td>{{ bd.fvBD.attributes.type }}</td>
    <td>{{ bd.fvBD.attributes.unicastRoute }}</td>
    <td>{{ bd.fvBD.attributes.unkMacUcastAct }}</td>
    <td>{{ bd.fvBD.attributes.unkMcastAct }}</td>
    <td>{{ bd.fvBD.attributes.v6unkMcastAct }}</td>
    <td>{{ bd.fvBD.attributes.vmac }}</td>
    <td>{{ bd.fvBD.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "Ctx" in api %}
<h1>Contexts</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Bridge Domain Enforced Enable</th>
    <th>IP Data Plane Learning</th>
    <th>Known Multicast Action</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>PC Enforce Directory</th>
    <th>PC Enforce Directory Updated</th>
    <th>PC Enforce Preference</th>
    <th>PC Tag</th>
    <th>Scope</th>
    <th>Seg</th>
    <th>VRF ID</th>
    <th>VRF Index</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for context in data_to_template['imdata'] %}
  <tr>
    <td>{{ context.fvCtx.attributes.name }}</td>
    <td>{{ context.fvCtx.attributes.nameAlias }}</td>
    <td>{{ context.fvCtx.attributes.descr }}</td>
    <td>{{ context.fvCtx.attributes.status }}</td>
    <td>{{ context.fvCtx.attributes.dn }}</td>
    <td>{{ context.fvCtx.attributes.uid }}</td>
    <td>{{ context.fvCtx.attributes.annotation }}</td>
    <td>{{ context.fvCtx.attributes.childAction }}</td>
    <td>{{ context.fvCtx.attributes.extMngdBy }}</td>
    <td>{{ context.fvCtx.attributes.lcOwn }}</td>
    <td>{{ context.fvCtx.attributes.monPolDn }}</td>
    <td>{{ context.fvCtx.attributes.userdom }}</td>
    <td>{{ context.fvCtx.attributes.bdEnforcedEnable }}</td>
    <td>{{ context.fvCtx.attributes.ipDataPlaneLearning }}</td>
    <td>{{ context.fvCtx.attributes.knwMcastAct }}</td>
    <td>{{ context.fvCtx.attributes.ownerKey }}</td>
    <td>{{ context.fvCtx.attributes.ownerTag }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfDir }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfDirUpdated }}</td>
    <td>{{ context.fvCtx.attributes.pcEnfPref }}</td>
    <td>{{ context.fvCtx.attributes.pcTag }}</td>
    <td>{{ context.fvCtx.attributes.scope }}</td>
    <td>{{ context.fvCtx.attributes.seg }}</td>
    <td>{{ context.fvCtx.attributes.vrfId }}</td>
    <td>{{ context.fvCtx.attributes.vrfIndex }}</td>
    <td>{{ context.fvCtx.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "Ap" in api %}
<h1>Application Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for application_profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ application_profile.fvAp.attributes.name }}</td>
    <td>{{ application_profile.fvAp.attributes.nameAlias }}</td>
    <td>{{ application_profile.fvAp.attributes.descr }}</td>
    <td>{{ application_profile.fvAp.attributes.status }}</td>
    <td>{{ application_profile.fvAp.attributes.dn }}</td>
    <td>{{ application_profile.fvAp.attributes.uid }}</td>
    <td>{{ application_profile.fvAp.attributes.annotation }}</td>
    <td>{{ application_profile.fvAp.attributes.childAction }}</td>
    <td>{{ application_profile.fvAp.attributes.extMngdBy }}</td>
    <td>{{ application_profile.fvAp.attributes.lcOwn }}</td>
    <td>{{ application_profile.fvAp.attributes.monPolDn }}</td>
    <td>{{ application_profile.fvAp.attributes.userdom }}</td>
    <td>{{ application_profile.fvAp.attributes.ownerKey }}</td>
    <td>{{ application_profile.fvAp.attributes.ownerTag }}</td>
    <td>{{ application_profile.fvAp.attributes.prio }}</td>
    <td>{{ application_profile.fvAp.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "l3extOut" in api %}
<h1>L3Outs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Description</th>
    <th>Status</th>
    <th>DN</th>
    <th>UID</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Monitoring Policy DN</th>
    <th>User Domain</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Enforce Route Control</th>
    <th>Target DSCP</th>
    <th>Modified Timestamp</th>
  </tr>
</thead>
<tbody>
{%-     for l3out in data_to_template['imdata'] %}
  <tr>
    <td>{{ l3out.l3extOut.attributes.name }}</td>
    <td>{{ l3out.l3extOut.attributes.nameAlias }}</td>
    <td>{{ l3out.l3extOut.attributes.descr }}</td>
    <td>{{ l3out.l3extOut.attributes.status }}</td>
    <td>{{ l3out.l3extOut.attributes.dn }}</td>
    <td>{{ l3out.l3extOut.attributes.uid }}</td>
    <td>{{ l3out.l3extOut.attributes.annotation }}</td>
    <td>{{ l3out.l3extOut.attributes.childAction }}</td>
    <td>{{ l3out.l3extOut.attributes.extMngdBy }}</td>
    <td>{{ l3out.l3extOut.attributes.lcOwn }}</td>
    <td>{{ l3out.l3extOut.attributes.monPolDn }}</td>
    <td>{{ l3out.l3extOut.attributes.userdom }}</td>
    <td>{{ l3out.l3extOut.attributes.ownerKey }}</td>
    <td>{{ l3out.l3extOut.attributes.ownerTag }}</td>
    <td>{{ l3out.l3extOut.attributes.prio }}</td>
    <td>{{ l3out.l3extOut.attributes.enforceRtctrl }}</td>
    <td>{{ l3out.l3extOut.attributes.targetDscp }}</td>
    <td>{{ l3out.l3extOut.attributes.modTs }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "l2extOut" in api %}
<h1>L2Outs</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>LC Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>    
{%-     for l2out in data_to_template['imdata'] %}
  <tr>
    <td>{{ l2out.l2extOut.attributes.name }}</td>
    <td>{{ l2out.l2extOut.attributes.nameAlias }}</td>
    <td>{{ l2out.l2extOut.attributes.annotation }}</td>
    <td>{{ l2out.l2extOut.attributes.childAction }}</td>
    <td>{{ l2out.l2extOut.attributes.descr }}</td>
    <td>{{ l2out.l2extOut.attributes.dn }}</td>
    <td>{{ l2out.l2extOut.attributes.extMngdBy }}</td>
    <td>{{ l2out.l2extOut.attributes.lcOwn }}</td>
    <td>{{ l2out.l2extOut.attributes.modTs }}</td>
    <td>{{ l2out.l2extOut.attributes.monPolDn }}</td>
    <td>{{ l2out.l2extOut.attributes.ownerKey }}</td>
    <td>{{ l2out.l2extOut.attributes.ownerTag }}</td>
    <td>{{ l2out.l2extOut.attributes.status }}</td>
    <td>{{ l2out.l2extOut.attributes.targetDscp }}</td>
    <td>{{ l2out.l2extOut.attributes.uid }}</td>
    <td>{{ l2out.l2extOut.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "topSystem" in api %}
<h1>Top System</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Address</th>
    <th>Bootstrap State</th>
    <th>Child Action</th>
    <th>Cluster Time Diff</th>
    <th>Configuration Issues</th>
    <th>Control Plane MTU</th>
    <th>Current Time</th>
    <th>DN</th>
    <th>Enforce Subnet Check</th>
    <th>ETEP Address</th>
    <th>Fabric Domain</th>
    <th>Fabric ID</th>
    <th>Fabric MAC</th>
    <th>ID</th>
    <th>Inband Mgmt Address</th>
    <th>Inband Mgmt Address6</th>
    <th>Inband Mgmt Address6 Mask</th>
    <th>Inband Mgmt Address Mask</th>
    <th>Inband Mgmt Gateway</th>
    <th>Inband Mgmt Gateway6</th>
    <th>Last Reboot Time</th>
    <th>Last Reset Reason</th>
    <th>LC Own</th>
    <th>Modified Timestamp</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>Name Alias</th>
    <th>Node Type</th>
    <th>Out of Band Mgmt Address</th>
    <th>Out of Band Mgmt Address6</th>
    <th>Out of Band Mgmt Address6 Mask</th>
    <th>Out of Band Mgmt Address Mask</th>
    <th>Out of Band Mgmt Gateway</th>
    <th>Out of Band Mgmt Gateway6</th>
    <th>Pod ID</th>
    <th>Remote Network ID</th>
    <th>Remote Node</th>
    <th>RL Oper Pod ID</th>
    <th>RL Routable Mode</th>
    <th>RL Direct Mode</th>
    <th>Role</th>
    <th>Serial Number</th>
    <th>Server Type</th>
    <th>Site ID</th>
    <th>State</th>
    <th>Status</th>
    <th>System Uptime</th>
    <th>TEP Pool</th>
    <th>Unicast XR EP Learn Disable</th>
    <th>Version</th>
    <th>Virtual Mode</th>
  </tr>
</thead>
<tbody>
{%-     for topSystem in data_to_template['imdata'] %}
  <tr>
    <td>{{ topSystem.topSystem.attributes.name }}</td>
    <td>{{ topSystem.topSystem.attributes.address }}</td>
    <td>{{ topSystem.topSystem.attributes.bootstrapState }}</td>
    <td>{{ topSystem.topSystem.attributes.childAction }}</td>
    <td>{{ topSystem.topSystem.attributes.clusterTimeDiff }}</td>
    <td>{{ topSystem.topSystem.attributes.configIssues }}</td>
    <td>{{ topSystem.topSystem.attributes.controlPlaneMTU }}</td>
    <td>{{ topSystem.topSystem.attributes.currentTime }}</td>
    <td>{{ topSystem.topSystem.attributes.dn }}</td>
    <td>{{ topSystem.topSystem.attributes.enforceSubnetCheck }}</td>
    <td>{{ topSystem.topSystem.attributes.etepAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricDomain }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricId }}</td>
    <td>{{ topSystem.topSystem.attributes.fabricMAC }}</td>
    <td>{{ topSystem.topSystem.attributes.id }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddr6Mask }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtAddrMask }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtGateway }}</td>
    <td>{{ topSystem.topSystem.attributes.inbMgmtGateway6 }}</td>
    <td>{{ topSystem.topSystem.attributes.lastRebootTime }}</td>
    <td>{{ topSystem.topSystem.attributes.lastResetReason }}</td>
    <td>{{ topSystem.topSystem.attributes.lcOwn }}</td>
    <td>{{ topSystem.topSystem.attributes.modTs }}</td>
    <td>{{ topSystem.topSystem.attributes.mode }}</td>
    <td>{{ topSystem.topSystem.attributes.monPolDn }}</td>
    <td>{{ topSystem.topSystem.attributes.nameAlias }}</td>
    <td>{{ topSystem.topSystem.attributes.nodeType }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr6 }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddr6Mask }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtAddrMask }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtGateway }}</td>
    <td>{{ topSystem.topSystem.attributes.oobMgmtGateway6 }}</td>
    <td>{{ topSystem.topSystem.attributes.podId }}</td>
    <td>{{ topSystem.topSystem.attributes.remoteNetworkId }}</td>
    <td>{{ topSystem.topSystem.attributes.remoteNode }}</td>
    <td>{{ topSystem.topSystem.attributes.rlOperPodId }}</td>
    <td>{{ topSystem.topSystem.attributes.rlRoutableMode }}</td>
    <td>{{ topSystem.topSystem.attributes.rldirectMode }}</td>
    <td>{{ topSystem.topSystem.attributes.role }}</td>
    <td>{{ topSystem.topSystem.attributes.serial }}</td>
    <td>{{ topSystem.topSystem.attributes.serverType }}</td>
    <td>{{ topSystem.topSystem.attributes.siteId }}</td>
    <td>{{ topSystem.topSystem.attributes.state }}</td>
    <td>{{ topSystem.topSystem.attributes.status }}</td>
    <td>{{ topSystem.topSystem.attributes.systemUpTime }}</td>
    <td>{{ topSystem.topSystem.attributes.tepPool }}</td>
    <td>{{ topSystem.topSystem.attributes.unicastXrEpLearnDisable }}</td>
    <td>{{ topSystem.topSystem.attributes.version }}</td>
    <td>{{ topSystem.topSystem.attributes.virtualMode }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "Subnet" in api %}
<h1>Subnets</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Config Issues</th>
    <th>Control</th>
    <th>Debug Message</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>IP</th>
    <th>IP Data Plane Learning</th>
    <th>LC Owner</th>
    <th>Monitoring Policy DN</th>
    <th>Preferred</th>
    <th>Scope</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>Virtual</th>
    <th>Last Modified</th>
  </tr>
</thead>
<tbody>    
{%-     for subnet in data_to_template['imdata'] %}
  <tr>
    <td>{{ subnet.fvSubnet.attributes.name }}</td>
    <td>{{ subnet.fvSubnet.attributes.nameAlias }}</td>
    <td>{{ subnet.fvSubnet.attributes.annotation }}</td>
    <td>{{ subnet.fvSubnet.attributes.childAction }}</td>
    <td>{{ subnet.fvSubnet.attributes.configIssues }}</td>
    <td>{{ subnet.fvSubnet.attributes.ctrl }}</td>
    <td>{{ subnet.fvSubnet.attributes.debugMessage }}</td>
    <td>{{ subnet.fvSubnet.attributes.descr }}</td>
    <td>{{ subnet.fvSubnet.attributes.dn }}</td>
    <td>{{ subnet.fvSubnet.attributes.extMngdBy }}</td>
    <td>{{ subnet.fvSubnet.attributes.ip }}</td>
    <td>{{ subnet.fvSubnet.attributes.ipDPLearning }}</td>
    <td>{{ subnet.fvSubnet.attributes.lcOwn }}</td>
    <td>{{ subnet.fvSubnet.attributes.monPolDn }}</td>
    <td>{{ subnet.fvSubnet.attributes.preferred }}</td>
    <td>{{ subnet.fvSubnet.attributes.scope }}</td>
    <td>{{ subnet.fvSubnet.attributes.status }}</td>
    <td>{{ subnet.fvSubnet.attributes.uid }}</td>
    <td>{{ subnet.fvSubnet.attributes.userdom }}</td>
    <td>{{ subnet.fvSubnet.attributes.virtual }}</td>
    <td>{{ subnet.fvSubnet.attributes.modTs }}</td>
</tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "CEp" in api %}
<h1>Endpoints</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>MAC</th>
    <th>Annotation</th>
    <th>Base EPG DN</th>
    <th>Bridge Domain DN</th>
    <th>Child Action</th>
    <th>Container Name</th>
    <th>DN</th>
    <th>Encapsulation</th>
    <th>ESG Use gDN</th>
    <th>Externally Managed By</th>
    <th>Full Fabric Path DN</th>
    <th>ID</th>
    <th>ID Endpoint DN</th>
    <th>LCC</th>
    <th>LC Owner</th>
    <th>Multicast Address</th>
    <th>Last Modified</th>
    <th>Monitor Policy DN</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>UUID</th>
    <th>VMM Source</th>
    <th>VRF DN</th>
  </tr>
</thead>
<tbody>    
{%-     for endpoint in data_to_template['imdata'] %}
  <tr>
    <td>{{ endpoint.fvCEp.attributes.name }}</td>
    <td>{{ endpoint.fvCEp.attributes.nameAlias }}</td>
    <td>{{ endpoint.fvCEp.attributes.mac }}</td>
    <td>{{ endpoint.fvCEp.attributes.annotation }}</td>
    <td>{{ endpoint.fvCEp.attributes.baseEpgDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.bdDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.childAction }}</td>
    <td>{{ endpoint.fvCEp.attributes.contName }}</td>
    <td>{{ endpoint.fvCEp.attributes.dn }}</td>
    <td>{{ endpoint.fvCEp.attributes.encap }}</td>
    <td>{{ endpoint.fvCEp.attributes.esgUsegDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.extMngdBy }}</td>
    <td>{{ endpoint.fvCEp.attributes.fabricPathDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.id }}</td>
    <td>{{ endpoint.fvCEp.attributes.idepdn }}</td>
    <td>{{ endpoint.fvCEp.attributes.lcC }}</td>
    <td>{{ endpoint.fvCEp.attributes.lcOwn }}</td>
    <td>{{ endpoint.fvCEp.attributes.mcastAddr }}</td>
    <td>{{ endpoint.fvCEp.attributes.modTs }}</td>
    <td>{{ endpoint.fvCEp.attributes.monPolDn }}</td>
    <td>{{ endpoint.fvCEp.attributes.status }}</td>
    <td>{{ endpoint.fvCEp.attributes.uid }}</td>
    <td>{{ endpoint.fvCEp.attributes.userdom }}</td>
    <td>{{ endpoint.fvCEp.attributes.uuid }}</td>
    <td>{{ endpoint.fvCEp.attributes.vmmSrc }}</td>
    <td>{{ endpoint.fvCEp.attributes.vrfDn }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "fabricNode" in api %}
<h1>Fabric Nodes</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>AD St</th>
    <th>Address</th>
    <th>Annotation</th>
    <th>APIC Type</th>
    <th>Child Action</th>
    <th>Delayed Heartbeat</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Fabric State</th>
    <th>ID</th>
    <th>Last State Modified</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Model</th>
    <th>Monitoring Policy DN</th>
    <th>Node Type</th>
    <th>Role</th>
    <th>Serial</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
    <th>Vendor</th>
    <th>Version</th>
  </tr>
</thead>
<tbody>  
{%-     for node in data_to_template['imdata'] %}
  <tr>
    <td>{{ node.fabricNode.attributes.name }}</td>
    <td>{{ node.fabricNode.attributes.nameAlias }}</td>
    <td>{{ node.fabricNode.attributes.adSt }}</td>
    <td>{{ node.fabricNode.attributes.address }}</td>
    <td>{{ node.fabricNode.attributes.annotation }}</td>
    <td>{{ node.fabricNode.attributes.apicType }}</td>
    <td>{{ node.fabricNode.attributes.childAction }}</td>
    <td>{{ node.fabricNode.attributes.delayedHeartbeat }}</td>
    <td>{{ node.fabricNode.attributes.dn }}</td>
    <td>{{ node.fabricNode.attributes.extMngdBy }}</td>
    <td>{{ node.fabricNode.attributes.fabricSt }}</td>
    <td>{{ node.fabricNode.attributes.id }}</td>
    <td>{{ node.fabricNode.attributes.lastStateModTs }}</td>
    <td>{{ node.fabricNode.attributes.lcOwn }}</td>
    <td>{{ node.fabricNode.attributes.modTs }}</td>
    <td>{{ node.fabricNode.attributes.model }}</td>
    <td>{{ node.fabricNode.attributes.monPolDn }}</td>
    <td>{{ node.fabricNode.attributes.nodeType }}</td>
    <td>{{ node.fabricNode.attributes.role }}</td>
    <td>{{ node.fabricNode.attributes.serial }}</td>
    <td>{{ node.fabricNode.attributes.status }}</td>
    <td>{{ node.fabricNode.attributes.uid }}</td>
    <td>{{ node.fabricNode.attributes.userdom }}</td>
    <td>{{ node.fabricNode.attributes.vendor }}</td>
    <td>{{ node.fabricNode.attributes.version }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "l1PhysIf" in api %}
<h1>Physical Interfaces</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Admin State</th>
    <th>Auto Negotiate</th>
    <th>Breakout Map</th>
    <th>Bandwidth</th>
    <th>Child Action</th>
    <th>Delay</th>
    <th>Description</th>
    <th>DFE Delay MS</th>
    <th>DN</th>
    <th>Dot1q EtherType</th>
    <th>Eth PM Cfg Failed Bmp</th>
    <th>Eth PM Cfg Failed Timestamp</th>
    <th>Eth PM Cfg State</th>
    <th>FCOT Channel Number</th>
    <th>FEC Mode</th>
    <th>ID</th>
    <th>Inherited Bandwidth</th>
    <th>Is Reflective Relay Config Supported</th>
    <th>Layer</th>
    <th>Local Owner</th>
    <th>Link Debounce</th>
    <th>Link Flap Error Max</th>
    <th>Link Flap Error Seconds</th>
    <th>Link Log</th>
    <th>MDIX</th>
    <th>Medium</th>
    <th>Last Modified</th>
    <th>Mode</th>
    <th>Monitoring Policy DN</th>
    <th>MTU</th>
    <th>Name</th>
    <th>Path S Description</th>
    <th>Port Physical Media Type</th>
    <th>Port T</th>
    <th>Priority Flow Control</th>
    <th>Reflective Relay Enable</th>
    <th>Router MAC</th>
    <th>SNMP Trap State</th>
    <th>Span Mode</th>
    <th>Speed</th>
    <th>Status</th>
    <th>Switching State</th>
    <th>Trunk Log</th>
    <th>Usage</th>
  </tr>
</thead>
<tbody>  
{%-     for outer_list in data_to_template %}
{%-         for interface in outer_list %}
  <tr>
    <td>{{ interface.l1PhysIf.attributes.adminSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.autoNeg }}</td>
    <td>{{ interface.l1PhysIf.attributes.brkoutMap }}</td>
    <td>{{ interface.l1PhysIf.attributes.bw }}</td>
    <td>{{ interface.l1PhysIf.attributes.childAction }}</td>
    <td>{{ interface.l1PhysIf.attributes.delay }}</td>
    <td>{{ interface.l1PhysIf.attributes.descr }}</td>
    <td>{{ interface.l1PhysIf.attributes.dfeDelayMs }}</td>
    <td>{{ interface.l1PhysIf.attributes.dn }}</td>
    <td>{{ interface.l1PhysIf.attributes.dot1qEtherType }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgFailedBmp }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgFailedTs }}</td>
    <td>{{ interface.l1PhysIf.attributes.ethpmCfgState }}</td>
    <td>{{ interface.l1PhysIf.attributes.fcotChannelNumber }}</td>
    <td>{{ interface.l1PhysIf.attributes.fecMode }}</td>
    <td>{{ interface.l1PhysIf.attributes.id }}</td>
    <td>{{ interface.l1PhysIf.attributes.inhBw }}</td>
    <td>{{ interface.l1PhysIf.attributes.isReflectiveRelayCfgSupported }}</td>
    <td>{{ interface.l1PhysIf.attributes.layer }}</td>
    <td>{{ interface.l1PhysIf.attributes.lcOwn }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkDebounce }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkFlapErrorMax }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkFlapErrorSeconds }}</td>
    <td>{{ interface.l1PhysIf.attributes.linkLog }}</td>
    <td>{{ interface.l1PhysIf.attributes.mdix }}</td>
    <td>{{ interface.l1PhysIf.attributes.medium }}</td>
    <td>{{ interface.l1PhysIf.attributes.modTs }}</td>
    <td>{{ interface.l1PhysIf.attributes.mode }}</td>
    <td>{{ interface.l1PhysIf.attributes.monPolDn }}</td>
    <td>{{ interface.l1PhysIf.attributes.mtu }}</td>
    <td>{{ interface.l1PhysIf.attributes.name }}</td>
    <td>{{ interface.l1PhysIf.attributes.pathSDescr }}</td>
    <td>{{ interface.l1PhysIf.attributes.portPhyMediaType }}</td>
    <td>{{ interface.l1PhysIf.attributes.portT }}</td>
    <td>{{ interface.l1PhysIf.attributes.prioFlowCtrl }}</td>
    <td>{{ interface.l1PhysIf.attributes.reflectiveRelayEn }}</td>
    <td>{{ interface.l1PhysIf.attributes.routerMac }}</td>
    <td>{{ interface.l1PhysIf.attributes.snmpTrapSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.spanMode }}</td>
    <td>{{ interface.l1PhysIf.attributes.speed }}</td>
    <td>{{ interface.l1PhysIf.attributes.status }}</td>
    <td>{{ interface.l1PhysIf.attributes.switchingSt }}</td>
    <td>{{ interface.l1PhysIf.attributes.trunkLog }}</td>
    <td>{{ interface.l1PhysIf.attributes.usage }}</td>
  </tr>
{%-         endfor %}
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "infraAccPortP" in api %}
<h1>Leaf Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraAccPortP.attributes.name }}</td>
    <td>{{ profile.infraAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraAccPortP.attributes.status }}</td>
    <td>{{ profile.infraAccPortP.attributes.uid }}</td>
    <td>{{ profile.infraAccPortP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "infraSpAccPortP" in api %}
<h1>Spine Interface Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraSpAccPortP.attributes.name }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.nameAlias }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.annotation }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.childAction }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.descr }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.dn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.lcOwn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.modTs }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.monPolDn }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerKey }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.ownerTag }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.status }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.uid }}</td>
    <td>{{ profile.infraSpAccPortP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "infraNodeP" in api %}
<h1>Leaf Switch Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraNodeP.attributes.name }}</td>
    <td>{{ profile.infraNodeP.attributes.nameAlias }}</td>
    <td>{{ profile.infraNodeP.attributes.annotation }}</td>
    <td>{{ profile.infraNodeP.attributes.childAction }}</td>
    <td>{{ profile.infraNodeP.attributes.descr }}</td>
    <td>{{ profile.infraNodeP.attributes.dn }}</td>
    <td>{{ profile.infraNodeP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraNodeP.attributes.lcOwn }}</td>
    <td>{{ profile.infraNodeP.attributes.modTs }}</td>
    <td>{{ profile.infraNodeP.attributes.monPolDn }}</td>
    <td>{{ profile.infraNodeP.attributes.ownerKey }}</td>
    <td>{{ profile.infraNodeP.attributes.ownerTag }}</td>
    <td>{{ profile.infraNodeP.attributes.status }}</td>
    <td>{{ profile.infraNodeP.attributes.uid }}</td>
    <td>{{ profile.infraNodeP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "infraSpineP" in api %}
<h1>Spine Switch Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraSpineP.attributes.name }}</td>
    <td>{{ profile.infraSpineP.attributes.nameAlias }}</td>
    <td>{{ profile.infraSpineP.attributes.annotation }}</td>
    <td>{{ profile.infraSpineP.attributes.childAction }}</td>
    <td>{{ profile.infraSpineP.attributes.descr }}</td>
    <td>{{ profile.infraSpineP.attributes.dn }}</td>
    <td>{{ profile.infraSpineP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraSpineP.attributes.lcOwn }}</td>
    <td>{{ profile.infraSpineP.attributes.modTs }}</td>
    <td>{{ profile.infraSpineP.attributes.monPolDn }}</td>
    <td>{{ profile.infraSpineP.attributes.ownerKey }}</td>
    <td>{{ profile.infraSpineP.attributes.ownerTag }}</td>
    <td>{{ profile.infraSpineP.attributes.status }}</td>
    <td>{{ profile.infraSpineP.attributes.uid }}</td>
    <td>{{ profile.infraSpineP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "fvnsVlanInstP" in api %}
<h1>VLAN Pools</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for pool in data_to_template['imdata'] %}
  <tr>
    <td>{{ pool.fvnsVlanInstP.attributes.name }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.nameAlias }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.allocMode }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.annotation }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.childAction }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.configIssues }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.descr }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.dn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.extMngdBy }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.lcOwn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.modTs }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.monPolDn }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.ownerKey }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.ownerTag }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.status }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.uid }}</td>
    <td>{{ pool.fvnsVlanInstP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "infraAttEntityP" in api %}
<h1>Attachable Access Entity Profiles</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Allocation Mode</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for profile in data_to_template['imdata'] %}
  <tr>
    <td>{{ profile.infraAttEntityP.attributes.name }}</td>
    <td>{{ profile.infraAttEntityP.attributes.nameAlias }}</td>
    <td>{{ profile.infraAttEntityP.attributes.allocMode }}</td>
    <td>{{ profile.infraAttEntityP.attributes.annotation }}</td>
    <td>{{ profile.infraAttEntityP.attributes.childAction }}</td>
    <td>{{ profile.infraAttEntityP.attributes.configIssues }}</td>
    <td>{{ profile.infraAttEntityP.attributes.descr }}</td>
    <td>{{ profile.infraAttEntityP.attributes.dn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.extMngdBy }}</td>
    <td>{{ profile.infraAttEntityP.attributes.lcOwn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.modTs }}</td>
    <td>{{ profile.infraAttEntityP.attributes.monPolDn }}</td>
    <td>{{ profile.infraAttEntityP.attributes.ownerKey }}</td>
    <td>{{ profile.infraAttEntityP.attributes.ownerTag }}</td>
    <td>{{ profile.infraAttEntityP.attributes.status }}</td>
    <td>{{ profile.infraAttEntityP.attributes.uid }}</td>
    <td>{{ profile.infraAttEntityP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "vzBrCP" in api %}
<h1>Contracts</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Privilege</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>Description</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Intent</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Priority</th>
    <th>Re Evaluate All</th>
    <th>Scope</th>
    <th>Status</th>
    <th>Target DSCP</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>   
{%-     for contract in data_to_template['imdata'] %}
  <tr>
    <td>{{ contract.vzBrCP.attributes.name }}</td>
    <td>{{ contract.vzBrCP.attributes.nameAlias }}</td>
    <td>{{ contract.vzBrCP.attributes.accessPrivilege }}</td>
    <td>{{ contract.vzBrCP.attributes.annotation }}</td>
    <td>{{ contract.vzBrCP.attributes.childAction }}</td>
    <td>{{ contract.vzBrCP.attributes.configIssues }}</td>
    <td>{{ contract.vzBrCP.attributes.descr }}</td>
    <td>{{ contract.vzBrCP.attributes.dn }}</td>
    <td>{{ contract.vzBrCP.attributes.extMngdBy }}</td>
    <td>{{ contract.vzBrCP.attributes.intent }}</td>
    <td>{{ contract.vzBrCP.attributes.lcOwn }}</td>
    <td>{{ contract.vzBrCP.attributes.modTs }}</td>
    <td>{{ contract.vzBrCP.attributes.monPolDn }}</td>
    <td>{{ contract.vzBrCP.attributes.ownerKey }}</td>
    <td>{{ contract.vzBrCP.attributes.ownerTag }}</td>
    <td>{{ contract.vzBrCP.attributes.prio }}</td>
    <td>{{ contract.vzBrCP.attributes.reevaluateAll }}</td>
    <td>{{ contract.vzBrCP.attributes.scope }}</td>
    <td>{{ contract.vzBrCP.attributes.status }}</td>
    <td>{{ contract.vzBrCP.attributes.targetDscp }}</td>
    <td>{{ contract.vzBrCP.attributes.uid }}</td>
    <td>{{ contract.vzBrCP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "vzEntry" in api %}
<h1>Filters</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Access Privilege</th>
    <th>Annotation</th>
    <th>Apply To Fragments</th>
    <th>ARP Opc</th>
    <th>Child Action</th>
    <th>Destination From Port</th>
    <th>Destination To Port</th>
    <th>Description</th>
    <th>DN</th>
    <th>EtherType</th>
    <th>Externally Managed By</th>
    <th>ICMPv4 T</th>
    <th>ICMPv6 T</th>
    <th>Local Owner</th>
    <th>Match DSCP</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Protocol</th>
    <th>Source From Port</th>
    <th>Source To Port</th>
    <th>Stateful</th>
    <th>Status</th>
    <th>TCP Rules</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody>  
{%-     for entry in data_to_template['imdata'] %}
  <tr>
    <td>{{ entry.vzEntry.attributes.name }}</td>
    <td>{{ entry.vzEntry.attributes.nameAlias }}</td>
    <td>{{ entry.vzEntry.attributes.accessPrivilege }}</td>
    <td>{{ entry.vzEntry.attributes.annotation }}</td>
    <td>{{ entry.vzEntry.attributes.applyToFrag }}</td>
    <td>{{ entry.vzEntry.attributes.arpOpc }}</td>
    <td>{{ entry.vzEntry.attributes.childAction }}</td>
    <td>{{ entry.vzEntry.attributes.dFromPort }}</td>
    <td>{{ entry.vzEntry.attributes.dToPort }}</td>
    <td>{{ entry.vzEntry.attributes.descr }}</td>
    <td>{{ entry.vzEntry.attributes.dn }}</td>
    <td>{{ entry.vzEntry.attributes.etherT }}</td>
    <td>{{ entry.vzEntry.attributes.extMngdBy }}</td>
    <td>{{ entry.vzEntry.attributes.icmpv4T }}</td>
    <td>{{ entry.vzEntry.attributes.icmpv6T }}</td>
    <td>{{ entry.vzEntry.attributes.lcOwn }}</td>
    <td>{{ entry.vzEntry.attributes.matchDscp }}</td>
    <td>{{ entry.vzEntry.attributes.modTs }}</td>
    <td>{{ entry.vzEntry.attributes.monPolDn }}</td>
    <td>{{ entry.vzEntry.attributes.prot }}</td>
    <td>{{ entry.vzEntry.attributes.sFromPort }}</td>
    <td>{{ entry.vzEntry.attributes.sToPort }}</td>
    <td>{{ entry.vzEntry.attributes.stateful }}</td>
    <td>{{ entry.vzEntry.attributes.status }}</td>
    <td>{{ entry.vzEntry.attributes.tcpRules }}</td>
    <td>{{ entry.vzEntry.attributes.uid }}</td>
    <td>{{ entry.vzEntry.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "physDomP" in api %}
<h1>Physical Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.physDomP.attributes.name }}</td>
    <td>{{ domain.physDomP.attributes.nameAlias }}</td>
    <td>{{ domain.physDomP.attributes.annotation }}</td>
    <td>{{ domain.physDomP.attributes.childAction }}</td>
    <td>{{ domain.physDomP.attributes.configIssues }}</td>
    <td>{{ domain.physDomP.attributes.dn }}</td>
    <td>{{ domain.physDomP.attributes.extMngdBy }}</td>
    <td>{{ domain.physDomP.attributes.lcOwn }}</td>
    <td>{{ domain.physDomP.attributes.modTs }}</td>
    <td>{{ domain.physDomP.attributes.monPolDn }}</td>
    <td>{{ domain.physDomP.attributes.ownerKey }}</td>
    <td>{{ domain.physDomP.attributes.ownerTag }}</td>
    <td>{{ domain.physDomP.attributes.status }}</td>
    <td>{{ domain.physDomP.attributes.uid }}</td>
    <td>{{ domain.physDomP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- else %}
{%- if "l3extDomP" in api %}
<h1>L3 Domains</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Annotation</th>
    <th>Child Action</th>
    <th>Configuration Issues</th>
    <th>DN</th>
    <th>Externally Managed By</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Owner Key</th>
    <th>Owner Tag</th>
    <th>Status</th>
    <th>UID</th>
    <th>User Domain</th>
  </tr>
</thead>
<tbody> 
{%-     for domain in data_to_template['imdata'] %}
  <tr>
    <td>{{ domain.l3extDomP.attributes.name }}</td>
    <td>{{ domain.l3extDomP.attributes.nameAlias }}</td>
    <td>{{ domain.l3extDomP.attributes.annotation }}</td>
    <td>{{ domain.l3extDomP.attributes.childAction }}</td>
    <td>{{ domain.l3extDomP.attributes.configIssues }}</td>
    <td>{{ domain.l3extDomP.attributes.dn }}</td>
    <td>{{ domain.l3extDomP.attributes.extMngdBy }}</td>
    <td>{{ domain.l3extDomP.attributes.lcOwn }}</td>
    <td>{{ domain.l3extDomP.attributes.modTs }}</td>
    <td>{{ domain.l3extDomP.attributes.monPolDn }}</td>
    <td>{{ domain.l3extDomP.attributes.ownerKey }}</td>
    <td>{{ domain.l3extDomP.attributes.ownerTag }}</td>
    <td>{{ domain.l3extDomP.attributes.status }}</td>
    <td>{{ domain.l3extDomP.attributes.uid }}</td>
    <td>{{ domain.l3extDomP.attributes.userdom }}</td>
  </tr>
{%-     endfor %}
</tbody>
</table>
{%- endif %}
{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}
{%- include 'datatable_footer.j2' %}