{%- if "Tenant" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,Owner Key,Owner Tag,User Domain,Modified Timestamp
{%-     for tenant in data_to_template['imdata'] %}
{{ tenant.fvTenant.attributes.name }},{{ tenant.fvTenant.attributes.nameAlias }},{{ tenant.fvTenant.attributes.descr }},{{ tenant.fvTenant.attributes.status }},{{ tenant.fvTenant.attributes.dn }},{{ tenant.fvTenant.attributes.uid }},{{ tenant.fvTenant.attributes.annotation }},{{ tenant.fvTenant.attributes.childAction }},{{ tenant.fvTenant.attributes.extMngdBy }},{{ tenant.fvTenant.attributes.lcOwn }},{{ tenant.fvTenant.attributes.monPolDn }},{{ tenant.fvTenant.attributes.ownerKey }},{{ tenant.fvTenant.attributes.ownerTag }},{{ tenant.fvTenant.attributes.userdom }},{{ tenant.fvTenant.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "AEPg" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Configuration Issues,Configuration State,Exception Tag,Flood On Encapsulation,Forward Control,Has Multicast Source,Is Attribute Based EPG,Is Shared Service Multicast Site EPG,Match T,PC Enforcement Preference,PC Tag,PC Tag Allocation Source,Preference Gr Member,Priority,Scope,Shutdown,Trigger State,TX Id,Modified Timestamp
{%-     for epg in data_to_template['imdata'] %}
{{ epg.fvAEPg.attributes.name }},{{ epg.fvAEPg.attributes.nameAlias }},{{ epg.fvAEPg.attributes.descr }},{{ epg.fvAEPg.attributes.status }},{{ epg.fvAEPg.attributes.dn }},{{ epg.fvAEPg.attributes.uid }},{{ epg.fvAEPg.attributes.annotation }},{{ epg.fvAEPg.attributes.childAction }},{{ epg.fvAEPg.attributes.extMngdBy }},{{ epg.fvAEPg.attributes.lcOwn }},{{ epg.fvAEPg.attributes.monPolDn }},{{ epg.fvAEPg.attributes.userdom }},{{ epg.fvAEPg.attributes.configIssues }},{{ epg.fvAEPg.attributes.configSt }},{{ epg.fvAEPg.attributes.exceptionTag }},{{ epg.fvAEPg.attributes.floodOnEncap }},{{ epg.fvAEPg.attributes.fwdCtrl }},{{ epg.fvAEPg.attributes.hasMcastSource }},{{ epg.fvAEPg.attributes.isAttrBasedEPg }},{{ epg.fvAEPg.attributes.isSharedSrvMsiteEPg }},{{ epg.fvAEPg.attributes.matchT }},{{ epg.fvAEPg.attributes.pcEnfPref }},{{ epg.fvAEPg.attributes.pcTag }},{{ epg.fvAEPg.attributes.pcTagAllocSrc }},{{ epg.fvAEPg.attributes.prefGrMemb }},{{ epg.fvAEPg.attributes.prio }},{{ epg.fvAEPg.attributes.scope }},{{ epg.fvAEPg.attributes.shutdown }},{{ epg.fvAEPg.attributes.triggerSt }},{{ epg.fvAEPg.attributes.txId }},{{ epg.fvAEPg.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "BD" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Configuration Issues,Optimize Wan Bandwidth,ARP Flood,Broadcast P,Endpoint Clear,Endpoint Move Detect Mode,Host Based Routing,Intersite BUM Traffic Allow,Intersite L2 Stretch,IP Learning,IPv6 Multicast Allow,Limit IP Learn To Subnets,Link Local Address,MAC,Multicast Allow,MTU,Multicase Destination Packet Action,Owner Key,Owner Tag,PC Tag,Scope,Segment,Type,Unicast Route,Unknown MAC Unicast Action,Unknown Multicast Action,IPv6 Unknown Multicast Action,Virtual MAC,Modified Timestamp
{%-     for bd in data_to_template['imdata'] %}
{{ bd.fvBD.attributes.name }},{{ bd.fvBD.attributes.nameAlias }},{{ bd.fvBD.attributes.descr }},{{ bd.fvBD.attributes.status }},{{ bd.fvBD.attributes.dn }},{{ bd.fvBD.attributes.uid }},{{ bd.fvBD.attributes.annotation }},{{ bd.fvBD.attributes.childAction }},{{ bd.fvBD.attributes.extMngdBy }},{{ bd.fvBD.attributes.lcOwn }},{{ bd.fvBD.attributes.monPolDn }},{{ bd.fvBD.attributes.userdom }},{{ bd.fvBD.attributes.configIssues }},{{ bd.fvBD.attributes.OptimizeWanBandwidth }},{{ bd.fvBD.attributes.arpFlood }},{{ bd.fvBD.attributes.bcastP }},{{ bd.fvBD.attributes.epClear }},{{ bd.fvBD.attributes.epMoveDetectMode }},{{ bd.fvBD.attributes.hostBasedRouting }},{{ bd.fvBD.attributes.intersiteBumTrafficAllow }},{{ bd.fvBD.attributes.intersiteL2Stretch }},{{ bd.fvBD.attributes.ipLearning }},{{ bd.fvBD.attributes.ipv6McastAllow }},{{ bd.fvBD.attributes.limitIpLearnToSubnets }},{{ bd.fvBD.attributes.llAddr }},{{ bd.fvBD.attributes.mac }},{{ bd.fvBD.attributes.mcastAllow }},{{ bd.fvBD.attributes.mtu }},{{ bd.fvBD.attributes.multiDstPktAct }},{{ bd.fvBD.attributes.ownerKey }},{{ bd.fvBD.attributes.ownerTag }},{{ bd.fvBD.attributes.pcTag }},{{ bd.fvBD.attributes.scope }},{{ bd.fvBD.attributes.seg }},{{ bd.fvBD.attributes.type }},{{ bd.fvBD.attributes.unicastRoute }},{{ bd.fvBD.attributes.unkMacUcastAct }},{{ bd.fvBD.attributes.unkMcastAct }},{{ bd.fvBD.attributes.v6unkMcastAct }},{{ bd.fvBD.attributes.vmac }},{{ bd.fvBD.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "Ctx" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Bridge Domain Enforced Enable,IP Data Plane Learning,Known Multicast Action,Owner Key,Owner Tag,PC Enforce Directory,PC Enforce Directory Updated,PC Enforce Preference,PC Tag,Scope,Seg,VRF ID,VRF Index,Modified Timestamp
{%-     for context in data_to_template['imdata'] %}
{{ context.fvCtx.attributes.name }},{{ context.fvCtx.attributes.nameAlias }},{{ context.fvCtx.attributes.descr }},{{ context.fvCtx.attributes.status }},{{ context.fvCtx.attributes.dn }},{{ context.fvCtx.attributes.uid }},{{ context.fvCtx.attributes.annotation }},{{ context.fvCtx.attributes.childAction }},{{ context.fvCtx.attributes.extMngdBy }},{{ context.fvCtx.attributes.lcOwn }},{{ context.fvCtx.attributes.monPolDn }},{{ context.fvCtx.attributes.userdom }},{{ context.fvCtx.attributes.bdEnforcedEnable }},{{ context.fvCtx.attributes.ipDataPlaneLearning }},{{ context.fvCtx.attributes.knwMcastAct }},{{ context.fvCtx.attributes.ownerKey }},{{ context.fvCtx.attributes.ownerTag }},{{ context.fvCtx.attributes.pcEnfDir }},{{ context.fvCtx.attributes.pcEnfDirUpdated }},{{ context.fvCtx.attributes.pcEnfPref }},{{ context.fvCtx.attributes.pcTag }},{{ context.fvCtx.attributes.scope }},{{ context.fvCtx.attributes.seg }},{{ context.fvCtx.attributes.vrfId }},{{ context.fvCtx.attributes.vrfIndex }},{{ context.fvCtx.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "Ap" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Owner Key,Owner Tag,Priority,Modified Timestamp
{%-     for application_profile in data_to_template['imdata'] %}
{{ application_profile.fvAp.attributes.name }},{{ application_profile.fvAp.attributes.nameAlias }},{{ application_profile.fvAp.attributes.descr }},{{ application_profile.fvAp.attributes.status }},{{ application_profile.fvAp.attributes.dn }},{{ application_profile.fvAp.attributes.uid }},{{ application_profile.fvAp.attributes.annotation }},{{ application_profile.fvAp.attributes.childAction }},{{ application_profile.fvAp.attributes.extMngdBy }},{{ application_profile.fvAp.attributes.lcOwn }},{{ application_profile.fvAp.attributes.monPolDn }},{{ application_profile.fvAp.attributes.userdom }},{{ application_profile.fvAp.attributes.ownerKey }},{{ application_profile.fvAp.attributes.ownerTag }},{{ application_profile.fvAp.attributes.prio }},{{ application_profile.fvAp.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "l3extOut" in api %}Name,Alias,Description,Status,DN,UID,Annotation,Child Action,Externally Managed By,Local Owner,Monitoring Policy DN,User Domain,Owner Key,Owner Tag,Priority,Enforce Route Control,Target DSCP,Modified Timestamp
{%-     for l3out in data_to_template['imdata'] %}
{{ l3out.l3extOut.attributes.name }},{{ l3out.l3extOut.attributes.nameAlias }},{{ l3out.l3extOut.attributes.descr }},{{ l3out.l3extOut.attributes.status }},{{ l3out.l3extOut.attributes.dn }},{{ l3out.l3extOut.attributes.uid }},{{ l3out.l3extOut.attributes.annotation }},{{ l3out.l3extOut.attributes.childAction }},{{ l3out.l3extOut.attributes.extMngdBy }},{{ l3out.l3extOut.attributes.lcOwn }},{{ l3out.l3extOut.attributes.monPolDn }},{{ l3out.l3extOut.attributes.userdom }},{{ l3out.l3extOut.attributes.ownerKey }},{{ l3out.l3extOut.attributes.ownerTag }},{{ l3out.l3extOut.attributes.prio }},{{ l3out.l3extOut.attributes.enforceRtctrl }},{{ l3out.l3extOut.attributes.targetDscp }},{{ l3out.l3extOut.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "l2extOut" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,LC Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,Target DSCP,UID,User Domain
{%-     for l2out in data_to_template['imdata'] %}
{{ l2out.l2extOut.attributes.name }},{{ l2out.l2extOut.attributes.nameAlias }},{{ l2out.l2extOut.attributes.annotation }},{{ l2out.l2extOut.attributes.childAction }},{{ l2out.l2extOut.attributes.descr }},{{ l2out.l2extOut.attributes.dn }},{{ l2out.l2extOut.attributes.extMngdBy }},{{ l2out.l2extOut.attributes.lcOwn }},{{ l2out.l2extOut.attributes.modTs }},{{ l2out.l2extOut.attributes.monPolDn }},{{ l2out.l2extOut.attributes.ownerKey }},{{ l2out.l2extOut.attributes.ownerTag }},{{ l2out.l2extOut.attributes.status }},{{ l2out.l2extOut.attributes.targetDscp }},{{ l2out.l2extOut.attributes.uid }},{{ l2out.l2extOut.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "topSystem" in api %}Name,Address,Bootstrap State,Child Action,Cluster Time Diff,Configuration Issues,Control Plane MTU,Current Time,DN,Enforce Subnet Check,ETEP Address,Fabric Domain,Fabric ID,Fabric MAC,ID,Inband Mgmt Address,Inband Mgmt Address6,Inband Mgmt Address6 Mask,Inband Mgmt Address Mask,Inband Mgmt Gateway,Inband Mgmt Gateway6,Last Reboot Time,Last Reset Reason,LC Own,Modified Timestamp,Mode,Monitoring Policy DN,Name Alias,Node Type,Out of Band Mgmt Address,Out of Band Mgmt Address6,Out of Band Mgmt Address6 Mask,Out of Band Mgmt Address Mask,Out of Band Mgmt Gateway,Out of Band Mgmt Gateway6,Pod ID,Remote Network ID,Remote Node,RL Oper Pod ID,RL Routable Mode,RL Direct Mode,Role,Serial Number,Server Type,Site ID,State,Status,System Uptime,TEP Pool,Unicast XR EP Learn Disable,Version,Virtual Mode
{%-     for topSystem in data_to_template['imdata'] %}
{{ topSystem.topSystem.attributes.name }},{{ topSystem.topSystem.attributes.address }},{{ topSystem.topSystem.attributes.bootstrapState }},{{ topSystem.topSystem.attributes.childAction }},{{ topSystem.topSystem.attributes.clusterTimeDiff }},{{ topSystem.topSystem.attributes.configIssues }},{{ topSystem.topSystem.attributes.controlPlaneMTU }},{{ topSystem.topSystem.attributes.currentTime }},{{ topSystem.topSystem.attributes.dn }},{{ topSystem.topSystem.attributes.enforceSubnetCheck }},{{ topSystem.topSystem.attributes.etepAddr }},{{ topSystem.topSystem.attributes.fabricDomain }},{{ topSystem.topSystem.attributes.fabricId }},{{ topSystem.topSystem.attributes.fabricMAC }},{{ topSystem.topSystem.attributes.id }},{{ topSystem.topSystem.attributes.inbMgmtAddr }},{{ topSystem.topSystem.attributes.inbMgmtAddr }},{{ topSystem.topSystem.attributes.inbMgmtAddr6Mask }},{{ topSystem.topSystem.attributes.inbMgmtAddrMask }},{{ topSystem.topSystem.attributes.inbMgmtGateway }},{{ topSystem.topSystem.attributes.inbMgmtGateway6 }},{{ topSystem.topSystem.attributes.lastRebootTime }},{{ topSystem.topSystem.attributes.lastResetReason }},{{ topSystem.topSystem.attributes.lcOwn }},{{ topSystem.topSystem.attributes.modTs }},{{ topSystem.topSystem.attributes.mode }},{{ topSystem.topSystem.attributes.monPolDn }},{{ topSystem.topSystem.attributes.nameAlias }},{{ topSystem.topSystem.attributes.nodeType }},{{ topSystem.topSystem.attributes.oobMgmtAddr }},{{ topSystem.topSystem.attributes.oobMgmtAddr6 }},{{ topSystem.topSystem.attributes.oobMgmtAddr6Mask }},{{ topSystem.topSystem.attributes.oobMgmtAddrMask }},{{ topSystem.topSystem.attributes.oobMgmtGateway }},{{ topSystem.topSystem.attributes.oobMgmtGateway6 }},{{ topSystem.topSystem.attributes.podId }},{{ topSystem.topSystem.attributes.remoteNetworkId }},{{ topSystem.topSystem.attributes.remoteNode }},{{ topSystem.topSystem.attributes.rlOperPodId }},{{ topSystem.topSystem.attributes.rlRoutableMode }},{{ topSystem.topSystem.attributes.rldirectMode }},{{ topSystem.topSystem.attributes.role }},{{ topSystem.topSystem.attributes.serial }},{{ topSystem.topSystem.attributes.serverType }},{{ topSystem.topSystem.attributes.siteId }},{{ topSystem.topSystem.attributes.state }},{{ topSystem.topSystem.attributes.status }},{{ topSystem.topSystem.attributes.systemUpTime }},{{ topSystem.topSystem.attributes.tepPool }},{{ topSystem.topSystem.attributes.unicastXrEpLearnDisable }},{{ topSystem.topSystem.attributes.version }},{{ topSystem.topSystem.attributes.virtualMode }}
{%-     endfor %}
{%- else %}
{%- if "Subnet" in api %}Name,Alias,Annotation,Child Action,Config Issues,Control,Debug Message,Description,DN,Externally Managed By,IP,IP Data Plane Learning,LC Owner,Monitoring Policy DN,Preferred,Scope,Status,UID,User Domain,Virtual,Last Modified
{%-     for subnet in data_to_template['imdata'] %}
{{ subnet.fvSubnet.attributes.name }},{{ subnet.fvSubnet.attributes.nameAlias }},{{ subnet.fvSubnet.attributes.annotation }},{{ subnet.fvSubnet.attributes.childAction }},{{ subnet.fvSubnet.attributes.configIssues }},{{ subnet.fvSubnet.attributes.ctrl }},{{ subnet.fvSubnet.attributes.debugMessage }},{{ subnet.fvSubnet.attributes.descr }},{{ subnet.fvSubnet.attributes.dn }},{{ subnet.fvSubnet.attributes.extMngdBy }},{{ subnet.fvSubnet.attributes.ip }},{{ subnet.fvSubnet.attributes.ipDPLearning }},{{ subnet.fvSubnet.attributes.lcOwn }},{{ subnet.fvSubnet.attributes.monPolDn }},{{ subnet.fvSubnet.attributes.preferred }},{{ subnet.fvSubnet.attributes.scope | replace(","," ")}},{{ subnet.fvSubnet.attributes.status }},{{ subnet.fvSubnet.attributes.uid }},{{ subnet.fvSubnet.attributes.userdom }},{{ subnet.fvSubnet.attributes.virtual }},{{ subnet.fvSubnet.attributes.modTs }}
{%-     endfor %}
{%- else %}
{%- if "CEp" in api %}Name,Name Alias,MAC,Annotation,Base EPG DN,Bridge Domain DN,Child Action,Container Name,DN,Encapsulation,ESG Use gDN,Externally Managed By,Full Fabric Path DN,POD,Path,Parent Interface,Interface Number,ID,ID Endpoint DN,LCC,LC Owner,Multicast Address,Last Modified,Monitor Policy DN,Status,UID,User Domain,UUID,VMM Source,VRF DN
{%-     for endpoint in data_to_template['imdata'] %}
{{ endpoint.fvCEp.attributes.name }},{{ endpoint.fvCEp.attributes.nameAlias }},{{ endpoint.fvCEp.attributes.mac }},{{ endpoint.fvCEp.attributes.annotation }},{{ endpoint.fvCEp.attributes.baseEpgDn }},{{ endpoint.fvCEp.attributes.bdDn }},{{ endpoint.fvCEp.attributes.childAction }},{{ endpoint.fvCEp.attributes.contName }},{{ endpoint.fvCEp.attributes.dn }},{{ endpoint.fvCEp.attributes.encap }},{{ endpoint.fvCEp.attributes.esgUsegDn }},{{ endpoint.fvCEp.attributes.extMngdBy }},{{ endpoint.fvCEp.attributes.fabricPathDn }},{%- if endpoint.fvCEp.attributes.fabricPathDn %}{{ endpoint.fvCEp.attributes.fabricPathDn | replace("topology/","") | replace("/",",") | replace("pathep-[","") | replace("]","")}}{%- if "eth" not in endpoint.fvCEp.attributes.fabricPathDn %},N/A{%- endif %}{%- else %}N/A,N/A,N/A,N/A{%- endif %},{{ endpoint.fvCEp.attributes.id }},{{ endpoint.fvCEp.attributes.idepdn }},{{ endpoint.fvCEp.attributes.lcC | replace(","," ") }},{{ endpoint.fvCEp.attributes.lcOwn }},{{ endpoint.fvCEp.attributes.mcastAddr }},{{ endpoint.fvCEp.attributes.modTs }},{{ endpoint.fvCEp.attributes.monPolDn }},{{ endpoint.fvCEp.attributes.status }},{{ endpoint.fvCEp.attributes.uid }},{{ endpoint.fvCEp.attributes.userdom }},{{ endpoint.fvCEp.attributes.uuid }},{{ endpoint.fvCEp.attributes.vmmSrc }},{{ endpoint.fvCEp.attributes.vrfDn }}
{%-     endfor %}
{%- else %}
{%- if "fabricNode" in api %}Name,Name Alias,AD St,Address,Annotation,APIC Type,Child Action,Delayed Heartbeat,DN,Externally Managed By,Fabric State,ID,Last State Modified,Local Owner,Last Modified,Model,Monitoring Policy DN,Node Type,Role,Serial,Status,UID,User Domain,Vendor,Version
{%-     for node in data_to_template['imdata'] %}
{{ node.fabricNode.attributes.name }},{{ node.fabricNode.attributes.nameAlias }},{{ node.fabricNode.attributes.adSt }},{{ node.fabricNode.attributes.address }},{{ node.fabricNode.attributes.annotation }},{{ node.fabricNode.attributes.apicType }},{{ node.fabricNode.attributes.childAction }},{{ node.fabricNode.attributes.delayedHeartbeat }},{{ node.fabricNode.attributes.dn }},{{ node.fabricNode.attributes.extMngdBy }},{{ node.fabricNode.attributes.fabricSt }},{{ node.fabricNode.attributes.id }},{{ node.fabricNode.attributes.lastStateModTs }},{{ node.fabricNode.attributes.lcOwn }},{{ node.fabricNode.attributes.modTs }},{{ node.fabricNode.attributes.model }},{{ node.fabricNode.attributes.monPolDn }},{{ node.fabricNode.attributes.nodeType }},{{ node.fabricNode.attributes.role }},{{ node.fabricNode.attributes.serial }},{{ node.fabricNode.attributes.status }},{{ node.fabricNode.attributes.uid }},{{ node.fabricNode.attributes.userdom }},{{ node.fabricNode.attributes.vendor | replace(","," ")}},{{ node.fabricNode.attributes.version }}
{%-     endfor %}
{%- else %}
{%- if "l1PhysIf" in api %}Admin State,Auto Negotiate,Breakout Map,Bandwidth,Child Action,Delay,Description,DFE Delay MS,DN,POD,Node,Dot1q EtherType,Eth PM Cfg Failed Bmp,Eth PM Cfg Failed Timestamp,Eth PM Cfg State,FCOT Channel Number,FEC Mode,ID,Inherited Bandwidth,Is Reflective Relay Config Supported,Layer,Local Owner,Link Debounce,Link Flap Error Max,Link Flap Error Seconds,Link Log,MDIX,Medium,Last Modified,Mode,Monitoring Policy DN,MTU,Name,Path S Description,Port Physical Media Type,Port T,Priority Flow Control,Reflective Relay Enable,Router MAC,SNMP Trap State,Span Mode,Speed,Status,Switching State,Trunk Log,Usage
{%-     for outer_list in data_to_template %}
{%-         for interface in outer_list %}
{{ interface.l1PhysIf.attributes.adminSt }},{{ interface.l1PhysIf.attributes.autoNeg }},{{ interface.l1PhysIf.attributes.brkoutMap }},{{ interface.l1PhysIf.attributes.bw }},{{ interface.l1PhysIf.attributes.childAction }},{{ interface.l1PhysIf.attributes.delay }},{{ interface.l1PhysIf.attributes.descr }},{{ interface.l1PhysIf.attributes.dfeDelayMs }},{{ interface.l1PhysIf.attributes.dn }},{{ interface.l1PhysIf.attributes.dn | replace("topology/","") | replace("/sys/phys-[","") | replace (interface.l1PhysIf.attributes.id,"") | replace("/",",") | replace("]","")}},{{ interface.l1PhysIf.attributes.dot1qEtherType }},{{ interface.l1PhysIf.attributes.ethpmCfgFailedBmp }},{{ interface.l1PhysIf.attributes.ethpmCfgFailedTs }},{{ interface.l1PhysIf.attributes.ethpmCfgState }},{{ interface.l1PhysIf.attributes.fcotChannelNumber }},{{ interface.l1PhysIf.attributes.fecMode }},{{ interface.l1PhysIf.attributes.id }},{{ interface.l1PhysIf.attributes.inhBw }},{{ interface.l1PhysIf.attributes.isReflectiveRelayCfgSupported }},{{ interface.l1PhysIf.attributes.layer }},{{ interface.l1PhysIf.attributes.lcOwn }},{{ interface.l1PhysIf.attributes.linkDebounce }},{{ interface.l1PhysIf.attributes.linkFlapErrorMax }},{{ interface.l1PhysIf.attributes.linkFlapErrorSeconds }},{{ interface.l1PhysIf.attributes.linkLog }},{{ interface.l1PhysIf.attributes.mdix }},{{ interface.l1PhysIf.attributes.medium }},{{ interface.l1PhysIf.attributes.modTs }},{{ interface.l1PhysIf.attributes.mode }},{{ interface.l1PhysIf.attributes.monPolDn }},{{ interface.l1PhysIf.attributes.mtu }},{{ interface.l1PhysIf.attributes.name }},{{ interface.l1PhysIf.attributes.pathSDescr }},{{ interface.l1PhysIf.attributes.portPhyMediaType }},{{ interface.l1PhysIf.attributes.portT }},{{ interface.l1PhysIf.attributes.prioFlowCtrl }},{{ interface.l1PhysIf.attributes.reflectiveRelayEn }},{{ interface.l1PhysIf.attributes.routerMac }},{{ interface.l1PhysIf.attributes.snmpTrapSt }},{{ interface.l1PhysIf.attributes.spanMode }},{{ interface.l1PhysIf.attributes.speed }},{{ interface.l1PhysIf.attributes.status }},{{ interface.l1PhysIf.attributes.switchingSt }},{{ interface.l1PhysIf.attributes.trunkLog }},{{ interface.l1PhysIf.attributes.usage | replace(","," ") }}
{%-         endfor %}
{%-     endfor %}
{%- else %}
{%- if "infraAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraAccPortP.attributes.name }},{{ profile.infraAccPortP.attributes.nameAlias }},{{ profile.infraAccPortP.attributes.annotation }},{{ profile.infraAccPortP.attributes.childAction }},{{ profile.infraAccPortP.attributes.descr }},{{ profile.infraAccPortP.attributes.dn }},{{ profile.infraAccPortP.attributes.extMngdBy }},{{ profile.infraAccPortP.attributes.lcOwn }},{{ profile.infraAccPortP.attributes.modTs }},{{ profile.infraAccPortP.attributes.monPolDn }},{{ profile.infraAccPortP.attributes.ownerKey }},{{ profile.infraAccPortP.attributes.ownerTag }},{{ profile.infraAccPortP.attributes.status }},{{ profile.infraAccPortP.attributes.uid }},{{ profile.infraAccPortP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "infraSpAccPortP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraSpAccPortP.attributes.name }},{{ profile.infraSpAccPortP.attributes.nameAlias }},{{ profile.infraSpAccPortP.attributes.annotation }},{{ profile.infraSpAccPortP.attributes.childAction }},{{ profile.infraSpAccPortP.attributes.descr }},{{ profile.infraSpAccPortP.attributes.dn }},{{ profile.infraSpAccPortP.attributes.extMngdBy }},{{ profile.infraSpAccPortP.attributes.lcOwn }},{{ profile.infraSpAccPortP.attributes.modTs }},{{ profile.infraSpAccPortP.attributes.monPolDn }},{{ profile.infraSpAccPortP.attributes.ownerKey }},{{ profile.infraSpAccPortP.attributes.ownerTag }},{{ profile.infraSpAccPortP.attributes.status }},{{ profile.infraSpAccPortP.attributes.uid }},{{ profile.infraSpAccPortP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "infraNodeP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraNodeP.attributes.name }},{{ profile.infraNodeP.attributes.nameAlias }},{{ profile.infraNodeP.attributes.annotation }},{{ profile.infraNodeP.attributes.childAction }},{{ profile.infraNodeP.attributes.descr }},{{ profile.infraNodeP.attributes.dn }},{{ profile.infraNodeP.attributes.extMngdBy }},{{ profile.infraNodeP.attributes.lcOwn }},{{ profile.infraNodeP.attributes.modTs }},{{ profile.infraNodeP.attributes.monPolDn }},{{ profile.infraNodeP.attributes.ownerKey }},{{ profile.infraNodeP.attributes.ownerTag }},{{ profile.infraNodeP.attributes.status }},{{ profile.infraNodeP.attributes.uid }},{{ profile.infraNodeP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "infraSpineP" in api %}Name,Name Alias,Annotation,Child Action,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraSpineP.attributes.name }},{{ profile.infraSpineP.attributes.nameAlias }},{{ profile.infraSpineP.attributes.annotation }},{{ profile.infraSpineP.attributes.childAction }},{{ profile.infraSpineP.attributes.descr }},{{ profile.infraSpineP.attributes.dn }},{{ profile.infraSpineP.attributes.extMngdBy }},{{ profile.infraSpineP.attributes.lcOwn }},{{ profile.infraSpineP.attributes.modTs }},{{ profile.infraSpineP.attributes.monPolDn }},{{ profile.infraSpineP.attributes.ownerKey }},{{ profile.infraSpineP.attributes.ownerTag }},{{ profile.infraSpineP.attributes.status }},{{ profile.infraSpineP.attributes.uid }},{{ profile.infraSpineP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "fvnsVlanInstP" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for pool in data_to_template['imdata'] %}
{{ pool.fvnsVlanInstP.attributes.name }},{{ pool.fvnsVlanInstP.attributes.nameAlias }},{{ pool.fvnsVlanInstP.attributes.allocMode }},{{ pool.fvnsVlanInstP.attributes.annotation }},{{ pool.fvnsVlanInstP.attributes.childAction }},{{ pool.fvnsVlanInstP.attributes.configIssues }},{{ pool.fvnsVlanInstP.attributes.descr }},{{ pool.fvnsVlanInstP.attributes.dn }},{{ pool.fvnsVlanInstP.attributes.extMngdBy }},{{ pool.fvnsVlanInstP.attributes.lcOwn }},{{ pool.fvnsVlanInstP.attributes.modTs }},{{ pool.fvnsVlanInstP.attributes.monPolDn }},{{ pool.fvnsVlanInstP.attributes.ownerKey }},{{ pool.fvnsVlanInstP.attributes.ownerTag }},{{ pool.fvnsVlanInstP.attributes.status }},{{ pool.fvnsVlanInstP.attributes.uid }},{{ pool.fvnsVlanInstP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "infraAttEntityP" in api %}Name,Name Alias,Allocation Mode,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for profile in data_to_template['imdata'] %}
{{ profile.infraAttEntityP.attributes.name }},{{ profile.infraAttEntityP.attributes.nameAlias }},{{ profile.infraAttEntityP.attributes.allocMode }},{{ profile.infraAttEntityP.attributes.annotation }},{{ profile.infraAttEntityP.attributes.childAction }},{{ profile.infraAttEntityP.attributes.configIssues }},{{ profile.infraAttEntityP.attributes.descr }},{{ profile.infraAttEntityP.attributes.dn }},{{ profile.infraAttEntityP.attributes.extMngdBy }},{{ profile.infraAttEntityP.attributes.lcOwn }},{{ profile.infraAttEntityP.attributes.modTs }},{{ profile.infraAttEntityP.attributes.monPolDn }},{{ profile.infraAttEntityP.attributes.ownerKey }},{{ profile.infraAttEntityP.attributes.ownerTag }},{{ profile.infraAttEntityP.attributes.status }},{{ profile.infraAttEntityP.attributes.uid }},{{ profile.infraAttEntityP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "vzBrCP" in api %}Name,Name Alias,Access Privilege,Annotation,Child Action,Configuration Issues,Description,DN,Externally Managed By,Intent,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Priority,Re Evaluate All,Scope,Status,Target DSCP,UID,User Domain
{%-     for contract in data_to_template['imdata'] %}
{{ contract.vzBrCP.attributes.name }},{{ contract.vzBrCP.attributes.nameAlias }},{{ contract.vzBrCP.attributes.accessPrivilege }},{{ contract.vzBrCP.attributes.annotation }},{{ contract.vzBrCP.attributes.childAction }},{{ contract.vzBrCP.attributes.configIssues }},{{ contract.vzBrCP.attributes.descr }},{{ contract.vzBrCP.attributes.dn }},{{ contract.vzBrCP.attributes.extMngdBy }},{{ contract.vzBrCP.attributes.intent }},{{ contract.vzBrCP.attributes.lcOwn }},{{ contract.vzBrCP.attributes.modTs }},{{ contract.vzBrCP.attributes.monPolDn }},{{ contract.vzBrCP.attributes.ownerKey }},{{ contract.vzBrCP.attributes.ownerTag }},{{ contract.vzBrCP.attributes.prio }},{{ contract.vzBrCP.attributes.reevaluateAll }},{{ contract.vzBrCP.attributes.scope }},{{ contract.vzBrCP.attributes.status }},{{ contract.vzBrCP.attributes.targetDscp }},{{ contract.vzBrCP.attributes.uid }},{{ contract.vzBrCP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "vzEntry" in api %}Name,Name Alias,Access Privilege,Annotation,Apply To Fragments,ARP Opc,Child Action,Destination From Port,Destination To Port,Description,DN,EtherType,Externally Managed By,ICMPv4 T,ICMPv6 T,Local Owner,Match DSCP,Last Modified,Monitoring Policy DN,Protocol,Source From Port,Source To Port,Stateful,Status,TCP Rules,UID,User Domain
{%-     for entry in data_to_template['imdata'] %}
{{ entry.vzEntry.attributes.name }},{{ entry.vzEntry.attributes.nameAlias }},{{ entry.vzEntry.attributes.accessPrivilege }},{{ entry.vzEntry.attributes.annotation }},{{ entry.vzEntry.attributes.applyToFrag }},{{ entry.vzEntry.attributes.arpOpc }},{{ entry.vzEntry.attributes.childAction }},{{ entry.vzEntry.attributes.dFromPort }},{{ entry.vzEntry.attributes.dToPort }},{{ entry.vzEntry.attributes.descr }},{{ entry.vzEntry.attributes.dn }},{{ entry.vzEntry.attributes.etherT }},{{ entry.vzEntry.attributes.extMngdBy }},{{ entry.vzEntry.attributes.icmpv4T }},{{ entry.vzEntry.attributes.icmpv6T }},{{ entry.vzEntry.attributes.lcOwn }},{{ entry.vzEntry.attributes.matchDscp }},{{ entry.vzEntry.attributes.modTs }},{{ entry.vzEntry.attributes.monPolDn }},{{ entry.vzEntry.attributes.prot }},{{ entry.vzEntry.attributes.sFromPort }},{{ entry.vzEntry.attributes.sToPort }},{{ entry.vzEntry.attributes.stateful }},{{ entry.vzEntry.attributes.status }},{{ entry.vzEntry.attributes.tcpRules }},{{ entry.vzEntry.attributes.uid }},{{ entry.vzEntry.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "physDomP" in api %}Name,Name Alias,Annotation,Child Action,Configuration Issues,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for domain in data_to_template['imdata'] %}
{{ domain.physDomP.attributes.name }},{{ domain.physDomP.attributes.nameAlias }},{{ domain.physDomP.attributes.annotation }},{{ domain.physDomP.attributes.childAction }},{{ domain.physDomP.attributes.configIssues }},{{ domain.physDomP.attributes.dn }},{{ domain.physDomP.attributes.extMngdBy }},{{ domain.physDomP.attributes.lcOwn }},{{ domain.physDomP.attributes.modTs }},{{ domain.physDomP.attributes.monPolDn }},{{ domain.physDomP.attributes.ownerKey }},{{ domain.physDomP.attributes.ownerTag }},{{ domain.physDomP.attributes.status }},{{ domain.physDomP.attributes.uid }},{{ domain.physDomP.attributes.userdom }}
{%-     endfor %}
{%- else %}
{%- if "l3extDomP" in api %}Name,Name Alias,Annotation,Child Action,Configuration Issues,DN,Externally Managed By,Local Owner,Last Modified,Monitoring Policy DN,Owner Key,Owner Tag,Status,UID,User Domain
{%-     for domain in data_to_template['imdata'] %}
{{ domain.l3extDomP.attributes.name }},{{ domain.l3extDomP.attributes.nameAlias }},{{ domain.l3extDomP.attributes.annotation }},{{ domain.l3extDomP.attributes.childAction }},{{ domain.l3extDomP.attributes.configIssues }},{{ domain.l3extDomP.attributes.dn }},{{ domain.l3extDomP.attributes.extMngdBy }},{{ domain.l3extDomP.attributes.lcOwn }},{{ domain.l3extDomP.attributes.modTs }},{{ domain.l3extDomP.attributes.monPolDn }},{{ domain.l3extDomP.attributes.ownerKey }},{{ domain.l3extDomP.attributes.ownerTag }},{{ domain.l3extDomP.attributes.status }},{{ domain.l3extDomP.attributes.uid }},{{ domain.l3extDomP.attributes.userdom }}
{%-     endfor %}
{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}{%- endif %}